diff src/fileio.c @ 41032:ef8a5e50dbe8

(Ffile_accessible_directory_p): Doc fix.
author Richard M. Stallman <rms@gnu.org>
date Wed, 14 Nov 2001 00:09:27 +0000
parents cdfd4d09b79a
children 02fcac02955b
line wrap: on
line diff
--- a/src/fileio.c	Wed Nov 14 00:09:06 2001 +0000
+++ b/src/fileio.c	Wed Nov 14 00:09:27 2001 +0000
@@ -3175,8 +3175,9 @@
 }
 
 DEFUN ("file-accessible-directory-p", Ffile_accessible_directory_p, Sfile_accessible_directory_p, 1, 1, 0,
-       doc: /* Return t if file FILENAME is the name of a directory as a file,
-and files in that directory can be opened by you.  In order to use a
+       doc: /* Return t if file FILENAME names a directory you can open.
+For the value to be t, FILENAME must specify the name of a directory as a file,
+and the directory must allow you to open files in it.  In order to use a
 directory as a buffer's current directory, this predicate must return true.
 A directory name spec may be given instead; then the value is t
 if the directory so specified exists and really is a readable and